@@ -89,19 +89,24 @@ import logging
 import secrets
 import socket
 import struct
-from collections.abc import Awaitable
+from asyncio import timeout as asyncio_timeout
+from asyncio.transports import DatagramTransport
+from collections.abc import Callable, Coroutine
+from dataclasses import dataclass
 from pprint import pformat as pf
-from typing import TYPE_CHECKING, Any, Callable, Dict, NamedTuple, Optional, Type, cast
+from typing import (
+    TYPE_CHECKING,
+    Annotated,
+    Any,
+    NamedTuple,
+    cast,
+)
 
 from aiohttp import ClientSession
-
-# When support for cpython older than 3.11 is dropped
-# async_timeout can be replaced with asyncio.timeout
-from async_timeout import timeout as asyncio_timeout
-from pydantic.v1 import BaseModel, ValidationError
+from mashumaro.config import BaseConfig
+from mashumaro.types import Alias
 
 from kasa import Device
-from kasa.aestransport import AesEncyptionSession, KeyPair
 from kasa.credentials import Credentials
 from kasa.device_factory import (
     get_device_class_from_family,
@@ -118,18 +123,20 @@ from kasa.exceptions import (
     TimeoutError,
     UnsupportedDeviceError,
 )
-from kasa.experimental import Experimental
 from kasa.iot.iotdevice import IotDevice
-from kasa.iotprotocol import REDACTORS as IOT_REDACTORS
+from kasa.json import DataClassJSONMixin
 from kasa.json import dumps as json_dumps
 from kasa.json import loads as json_loads
-from kasa.protocol import mask_mac, redact_data
-from kasa.xortransport import XorEncryption
+from kasa.protocols.iotprotocol import REDACTORS as IOT_REDACTORS
+from kasa.protocols.protocol import mask_mac, redact_data
+from kasa.transports.aestransport import AesEncyptionSession, KeyPair
+from kasa.transports.xortransport import XorEncryption
 
 _LOGGER = logging.getLogger(__name__)
 
 if TYPE_CHECKING:
-    from kasa import BaseProtocol, BaseTransport
+    from kasa import BaseProtocol
+    from kasa.transports import BaseTransport
 
 
 class ConnectAttempt(NamedTuple):
@@ -140,10 +147,10 @@ class ConnectAttempt(NamedTuple):
     device: type
 
 
-OnDiscoveredCallable = Callable[[Device], Awaitable[None]]
-OnUnsupportedCallable = Callable[[UnsupportedDeviceError], Awaitable[None]]
+OnDiscoveredCallable = Callable[[Device], Coroutine]
+OnUnsupportedCallable = Callable[[UnsupportedDeviceError], Coroutine]
 OnConnectAttemptCallable = Callable[[ConnectAttempt, bool], None]
-DeviceDict = Dict[str, Device]
+DeviceDict = dict[str, Device]
 
 NEW_DISCOVERY_REDACTORS: dict[str, Callable[[Any], Any] | None] = {
     "device_id": lambda x: "REDACTED_" + x[9::],
@@ -156,7 +163,7 @@ class _AesDiscoveryQuery:
     keypair: KeyPair | None = None
 
     @classmethod
-    def generate_query(cls):
+    def generate_query(cls) -> bytearray:
         if not cls.keypair:
             cls.keypair = KeyPair.create_key_pair(key_size=2048)
         secret = secrets.token_bytes(4)
@@ -215,7 +222,7 @@ class _DiscoverProtocol(asyncio.DatagramProtocol):
         credentials: Credentials | None = None,
         timeout: int | None = None,
     ) -> None:
-        self.transport = None
+        self.transport: DatagramTransport | None = None
         self.discovery_packets = discovery_packets
         self.interface = interface
         self.on_discovered = on_discovered
@@ -239,16 +246,19 @@ class _DiscoverProtocol(asyncio.DatagramProtocol):
         self.target_discovered: bool = False
         self._started_event = asyncio.Event()
 
-    def _run_callback_task(self, coro):
-        task = asyncio.create_task(coro)
+    def _run_callback_task(self, coro: Coroutine) -> None:
+        task: asyncio.Task = asyncio.create_task(coro)
         self.callback_tasks.append(task)
 
-    async def wait_for_discovery_to_complete(self):
+    async def wait_for_discovery_to_complete(self) -> None:
         """Wait for the discovery task to complete."""
         # Give some time for connection_made event to be received
         async with asyncio_timeout(self.DISCOVERY_START_TIMEOUT):
             await self._started_event.wait()
         try:
+            if TYPE_CHECKING:
+                assert isinstance(self.discover_task, asyncio.Task)
+
             await self.discover_task
         except asyncio.CancelledError:
             # if target_discovered then cancel was called internally
@@ -257,11 +267,11 @@ class _DiscoverProtocol(asyncio.DatagramProtocol):
         # Wait for any pending callbacks to complete
         await asyncio.gather(*self.callback_tasks)
 
-    def connection_made(self, transport) -> None:
+    def connection_made(self, transport: DatagramTransport) -> None:  # type: ignore[override]
         """Set socket options for broadcasting."""
-        self.transport = transport
+        self.transport = cast(DatagramTransport, transport)
 
-        sock = transport.get_extra_info("socket")
+        sock = self.transport.get_extra_info("socket")
         sock.setsockopt(socket.SOL_SOCKET, socket.SO_BROADCAST, 1)
         try:
             sock.setsockopt(socket.SOL_SOCKET, socket.SO_REUSEADDR, 1)
@@ -292,7 +302,11 @@ class _DiscoverProtocol(asyncio.DatagramProtocol):
             self.transport.sendto(aes_discovery_query, self.target_2)  # type: ignore
             await asyncio.sleep(sleep_between_packets)
 
-    def datagram_received(self, data, addr) -> None:
+    def datagram_received(
+        self,
+        data: bytes,
+        addr: tuple[str, int],
+    ) -> None:
         """Handle discovery responses."""
         if TYPE_CHECKING:
             assert _AesDiscoveryQuery.keypair
@@ -338,18 +352,18 @@ class _DiscoverProtocol(asyncio.DatagramProtocol):
 
         self._handle_discovered_event()
 
-    def _handle_discovered_event(self):
+    def _handle_discovered_event(self) -> None:
         """If target is in seen_hosts cancel discover_task."""
         if self.target in self.seen_hosts:
             self.target_discovered = True
             if self.discover_task:
                 self.discover_task.cancel()
 
-    def error_received(self, ex):
+    def error_received(self, ex: Exception) -> None:
         """Handle asyncio.Protocol errors."""
         _LOGGER.error("Got error: %s", ex)
 
-    def connection_lost(self, ex):  # pragma: no cover
+    def connection_lost(self, ex: Exception | None) -> None:  # pragma: no cover
         """Cancel the discover task if running."""
         if self.discover_task:
             self.discover_task.cancel()
@@ -372,17 +386,17 @@ class Discover:
     @staticmethod
     async def discover(
         *,
-        target="255.255.255.255",
-        on_discovered=None,
-        discovery_timeout=5,
-        discovery_packets=3,
-        interface=None,
-        on_unsupported=None,
-        credentials=None,
+        target: str = "255.255.255.255",
+        on_discovered: OnDiscoveredCallable | None = None,
+        discovery_timeout: int = 5,
+        discovery_packets: int = 3,
+        interface: str | None = None,
+        on_unsupported: OnUnsupportedCallable | None = None,
+        credentials: Credentials | None = None,
         username: str | None = None,
         password: str | None = None,
-        port=None,
-        timeout=None,
+        port: int | None = None,
+        timeout: int | None = None,
     ) -> DeviceDict:
         """Discover supported devices.
 
@@ -568,9 +582,8 @@ class Discover:
         main_device_families = {
             Device.Family.SmartTapoPlug,
             Device.Family.IotSmartPlugSwitch,
+            Device.Family.SmartIpCamera,
         }
-        if Experimental.enabled():
-            main_device_families.add(Device.Family.SmartIpCamera)
         candidates: dict[
             tuple[type[BaseProtocol], type[BaseTransport], type[Device]],
             tuple[BaseProtocol, DeviceConfig],
@@ -629,14 +642,14 @@ class Discover:
     def _get_device_class(info: dict) -> type[Device]:
         """Find SmartDevice subclass for device described by passed data."""
         if "result" in info:
-            discovery_result = DiscoveryResult(**info["result"])
+            discovery_result = DiscoveryResult.from_dict(info["result"])
             https = discovery_result.mgt_encrypt_schm.is_support_https
             dev_class = get_device_class_from_family(
                 discovery_result.device_type, https=https
             )
             if not dev_class:
                 raise UnsupportedDeviceError(
-                    "Unknown device type: %s" % discovery_result.device_type,
+                    f"Unknown device type: {discovery_result.device_type}",
                     discovery_result=info,
                 )
             return dev_class
@@ -657,7 +670,7 @@ class Discover:
             data = redact_data(info, IOT_REDACTORS) if Discover._redact_data else info
             _LOGGER.debug("[DISCOVERY] %s << %s", config.host, pf(data))
 
-        device_class = cast(Type[IotDevice], Discover._get_device_class(info))
+        device_class = cast(type[IotDevice], Discover._get_device_class(info))
         device = device_class(config.host, config=config)
         sys_info = info["system"]["get_sysinfo"]
         if device_type := sys_info.get("mic_type", sys_info.get("type")):
@@ -702,13 +715,10 @@ class Discover:
             raise KasaException(
                 f"Unable to read response from device: {config.host}: {ex}"
             ) from ex
+
         try:
-            discovery_result = DiscoveryResult(**info["result"])
-            if (
-                encrypt_info := discovery_result.encrypt_info
-            ) and encrypt_info.sym_schm == "AES":
-                Discover._decrypt_discovery_data(discovery_result)
-        except ValidationError as ex:
+            discovery_result = DiscoveryResult.from_dict(info["result"])
+        except Exception as ex:
             if debug_enabled:
                 data = (
                     redact_data(info, NEW_DISCOVERY_REDACTORS)
@@ -725,18 +735,31 @@ class Discover:
                 host=config.host,
             ) from ex
 
+        # Decrypt the data
+        if (
+            encrypt_info := discovery_result.encrypt_info
+        ) and encrypt_info.sym_schm == "AES":
+            try:
+                Discover._decrypt_discovery_data(discovery_result)
+            except Exception:
+                _LOGGER.exception(
+                    "Unable to decrypt discovery data %s: %s", config.host, data
+                )
+
         type_ = discovery_result.device_type
         encrypt_schm = discovery_result.mgt_encrypt_schm
+
         try:
             if not (encrypt_type := encrypt_schm.encrypt_type) and (
                 encrypt_info := discovery_result.encrypt_info
             ):
                 encrypt_type = encrypt_info.sym_schm
+
             if not encrypt_type:
                 raise UnsupportedDeviceError(
                     f"Unsupported device {config.host} of type {type_} "
                     + "with no encryption type",
-                    discovery_result=discovery_result.get_dict(),
+                    discovery_result=discovery_result.to_dict(),
                     host=config.host,
                 )
             config.connection_type = DeviceConnectionParameters.from_values(
@@ -749,28 +772,30 @@ class Discover:
             raise UnsupportedDeviceError(
                 f"Unsupported device {config.host} of type {type_} "
                 + f"with encrypt_type {discovery_result.mgt_encrypt_schm.encrypt_type}",
-                discovery_result=discovery_result.get_dict(),
+                discovery_result=discovery_result.to_dict(),
                 host=config.host,
             ) from ex
+
         if (
             device_class := get_device_class_from_family(
                 type_, https=encrypt_schm.is_support_https
             )
         ) is None:
-            _LOGGER.warning("Got unsupported device type: %s", type_)
+            _LOGGER.debug("Got unsupported device type: %s", type_)
             raise UnsupportedDeviceError(
                 f"Unsupported device {config.host} of type {type_}: {info}",
-                discovery_result=discovery_result.get_dict(),
+                discovery_result=discovery_result.to_dict(),
                 host=config.host,
             )
+
         if (protocol := get_protocol(config)) is None:
-            _LOGGER.warning(
+            _LOGGER.debug(
                 "Got unsupported connection type: %s", config.connection_type.to_dict()
             )
             raise UnsupportedDeviceError(
                 f"Unsupported encryption scheme {config.host} of "
                 + f"type {config.connection_type.to_dict()}: {info}",
-                discovery_result=discovery_result.get_dict(),
+                discovery_result=discovery_result.to_dict(),
                 host=config.host,
             )
 
@@ -781,24 +806,38 @@ class Discover:
                 else info
             )
             _LOGGER.debug("[DISCOVERY] %s << %s", config.host, pf(data))
+
         device = device_class(config.host, protocol=protocol)
 
-        di = discovery_result.get_dict()
+        di = discovery_result.to_dict()
         di["model"], _, _ = discovery_result.device_model.partition("(")
         device.update_from_discover_info(di)
         return device
 
 
-class EncryptionScheme(BaseModel):
+class _DiscoveryBaseMixin(DataClassJSONMixin):
+    """Base class for serialization mixin."""
+
+    class Config(BaseConfig):
+        """Serialization config."""
+
+        omit_none = True
+        omit_default = True
+        serialize_by_alias = True
+
+
+@dataclass
+class EncryptionScheme(_DiscoveryBaseMixin):
     """Base model for encryption scheme of discovery result."""
 
     is_support_https: bool
-    encrypt_type: Optional[str]  # noqa: UP007
-    http_port: Optional[int] = None  # noqa: UP007
-    lv: Optional[int] = None  # noqa: UP007
+    encrypt_type: str | None = None
+    http_port: int | None = None
+    lv: int | None = None
 
 
-class EncryptionInfo(BaseModel):
+@dataclass
+class EncryptionInfo(_DiscoveryBaseMixin):
     """Base model for encryption info of discovery result."""
 
     sym_schm: str
@@ -806,33 +845,26 @@ class EncryptionInfo(BaseModel):
     data: str
 
 
-class DiscoveryResult(BaseModel):
+@dataclass
+class DiscoveryResult(_DiscoveryBaseMixin):
     """Base model for discovery result."""
 
     device_type: str
     device_model: str
-    device_name: Optional[str]  # noqa: UP007
+    device_id: str
     ip: str
     mac: str
     mgt_encrypt_schm: EncryptionScheme
-    encrypt_info: Optional[EncryptionInfo] = None  # noqa: UP007
-    encrypt_type: Optional[list[str]] = None  # noqa: UP007
-    decrypted_data: Optional[dict] = None  # noqa: UP007
-    device_id: str
+    device_name: str | None = None
+    encrypt_info: EncryptionInfo | None = None
+    encrypt_type: list[str] | None = None
+    decrypted_data: dict | None = None
+    is_reset_wifi: Annotated[bool | None, Alias("isResetWiFi")] = None
 
-    firmware_version: Optional[str] = None  # noqa: UP007
-    hardware_version: Optional[str] = None  # noqa: UP007
-    hw_ver: Optional[str] = None  # noqa: UP007
-    owner: Optional[str] = None  # noqa: UP007
-    is_support_iot_cloud: Optional[bool] = None  # noqa: UP007
-    obd_src: Optional[str] = None  # noqa: UP007
-    factory_default: Optional[bool] = None  # noqa: UP007
-
-    def get_dict(self) -> dict:
-        """Return a dict for this discovery result.
-
-        containing only the values actually set and with aliases as field names.
-        """
-        return self.dict(
-            by_alias=False, exclude_unset=True, exclude_none=True, exclude_defaults=True
-        )
+    firmware_version: str | None = None
+    hardware_version: str | None = None
+    hw_ver: str | None = None
+    owner: str | None = None
+    is_support_iot_cloud: bool | None = None
+    obd_src: str | None = None
+    factory_default: bool | None = None
