@@ -6,6 +6,7 @@ from .led import Led
 from .light import Light, LightState
 from .lighteffect import LightEffect
 from .lightpreset import LightPreset
+from .thermostat import Thermostat, ThermostatState
 from .time import Time
 
 __all__ = [
@@ -16,5 +17,7 @@ __all__ = [
     "LightEffect",
     "LightState",
     "LightPreset",
+    "Thermostat",
+    "ThermostatState",
     "Time",
 ]
