@@ -3,36 +3,46 @@
 from __future__ import annotations
 
 from collections.abc import Sequence
-from dataclasses import asdict
-from typing import TYPE_CHECKING, Optional
+from dataclasses import asdict, dataclass
+from typing import TYPE_CHECKING
 
-from pydantic.v1 import BaseModel, Field
+from mashumaro.config import BaseConfig
 
 from ...exceptions import KasaException
 from ...interfaces import LightPreset as LightPresetInterface
 from ...interfaces import LightState
+from ...json import DataClassJSONMixin
 from ...module import Module
 from ..iotmodule import IotModule
 
 if TYPE_CHECKING:
     pass
 
+# type ignore can be removed after migration mashumaro:
+# error: Signature of "__replace__" incompatible with supertype "LightState"
 
-class IotLightPreset(BaseModel, LightState):
+
+@dataclass(kw_only=True, repr=False)
+class IotLightPreset(DataClassJSONMixin, LightState):  # type: ignore[override]
     """Light configuration preset."""
 
-    index: int = Field(kw_only=True)
-    brightness: int = Field(kw_only=True)
+    class Config(BaseConfig):
+        """Config class."""
+
+        omit_none = True
+
+    index: int
+    brightness: int
 
     # These are not available for effect mode presets on light strips
-    hue: Optional[int] = Field(kw_only=True, default=None)  # noqa: UP007
-    saturation: Optional[int] = Field(kw_only=True, default=None)  # noqa: UP007
-    color_temp: Optional[int] = Field(kw_only=True, default=None)  # noqa: UP007
+    hue: int | None = None
+    saturation: int | None = None
+    color_temp: int | None = None
 
     # Variables for effect mode presets
-    custom: Optional[int] = Field(kw_only=True, default=None)  # noqa: UP007
-    id: Optional[str] = Field(kw_only=True, default=None)  # noqa: UP007
-    mode: Optional[int] = Field(kw_only=True, default=None)  # noqa: UP007
+    custom: int | None = None
+    id: str | None = None
+    mode: int | None = None
 
 
 class LightPreset(IotModule, LightPresetInterface):
@@ -41,10 +51,10 @@ class LightPreset(IotModule, LightPresetInterface):
     _presets: dict[str, IotLightPreset]
     _preset_list: list[str]
 
-    def _post_update_hook(self):
+    async def _post_update_hook(self) -> None:
         """Update the internal presets."""
         self._presets = {
-            f"Light preset {index+1}": IotLightPreset(**vals)
+            f"Light preset {index+1}": IotLightPreset.from_dict(vals)
             for index, vals in enumerate(self.data["preferred_state"])
             # Devices may list some light effects along with normal presets but these
             # are handled by the LightEffect module so exclude preferred states with id
@@ -93,7 +103,7 @@ class LightPreset(IotModule, LightPresetInterface):
     async def set_preset(
         self,
         preset_name: str,
-    ) -> None:
+    ) -> dict:
         """Set a light preset for the device."""
         light = self._device.modules[Module.Light]
         if preset_name == self.PRESET_NOT_SET:
@@ -104,7 +114,7 @@ class LightPreset(IotModule, LightPresetInterface):
         elif (preset := self._presets.get(preset_name)) is None:  # type: ignore[assignment]
             raise ValueError(f"{preset_name} is not a valid preset: {self.preset_list}")
 
-        await light.set_state(preset)
+        return await light.set_state(preset)
 
     @property
     def has_save_preset(self) -> bool:
@@ -115,7 +125,7 @@ class LightPreset(IotModule, LightPresetInterface):
         self,
         preset_name: str,
         preset_state: LightState,
-    ) -> None:
+    ) -> dict:
         """Update the preset with preset_name with the new preset_info."""
         if len(self._presets) == 0:
             raise KasaException("Device does not supported saving presets")
@@ -129,7 +139,7 @@ class LightPreset(IotModule, LightPresetInterface):
 
         return await self.call("set_preferred_state", state)
 
-    def query(self):
+    def query(self) -> dict:
         """Return the base query."""
         return {}
 
@@ -142,7 +152,7 @@ class LightPreset(IotModule, LightPresetInterface):
             if "id" not in vals
         ]
 
-    async def _deprecated_save_preset(self, preset: IotLightPreset):
+    async def _deprecated_save_preset(self, preset: IotLightPreset) -> dict:
         """Save a setting preset.
 
         You can either construct a preset object manually, or pass an existing one
@@ -154,4 +164,4 @@ class LightPreset(IotModule, LightPresetInterface):
         if preset.index >= len(self._presets):
             raise KasaException("Invalid preset index")
 
-        return await self.call("set_preferred_state", preset.dict(exclude_none=True))
+        return await self.call("set_preferred_state", preset.to_dict())
